@@ -4,12 +4,12 @@ use {
 };
 
 #[derive(Accounts)]
-#[instruction(bump: u8, mint: Pubkey)]
+#[instruction(mint: Pubkey)]
 pub struct InitMintCounterCtx<'info> {
     #[account(
         init,
         payer = payer,
-        seeds = [MINT_COUNTER_SEED.as_bytes(), mint.as_ref()], bump = bump,
+        seeds = [MINT_COUNTER_SEED.as_bytes(), mint.as_ref()], bump,
         space = MINT_COUNTER_SIZE,
     )]
     mint_counter: Box<Account<'info, MintCounter>>,
@@ -19,9 +19,9 @@ pub struct InitMintCounterCtx<'info> {
     system_program: Program<'info, System>,
 }
 
-pub fn handler(ctx: Context<InitMintCounterCtx>, bump: u8, _mint: Pubkey) -> ProgramResult {
+pub fn handler(ctx: Context<InitMintCounterCtx>, _mint: Pubkey) -> ProgramResult {
     let mint_counter = &mut ctx.accounts.mint_counter;
-    mint_counter.bump = bump;
+    mint_counter.bump = *ctx.bumps.get("mint_counter").unwrap();
     mint_counter.count = 0;
     return Ok(())
 }
\ No newline at end of file
