@@ -7,6 +7,7 @@ pub mod set_transfer_authority;
 pub mod add_invalidator;
 pub mod create_claim_receipt;
 pub mod create_transfer_receipt;
+pub mod claim_receipt_mint;
 pub mod issue;
 pub mod unissue;
 pub mod claim;
@@ -23,6 +24,7 @@ pub use set_transfer_authority::*;
 pub use add_invalidator::*;
 pub use create_claim_receipt::*;
 pub use create_transfer_receipt::*;
+pub use claim_receipt_mint::*;
 pub use issue::*;
 pub use unissue::*;
 pub use claim::*;
